Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(447)

Unified Diff: chrome/browser/chromeos/login/user_manager.h

Issue 10384079: Reland "Implement random wallpaper feature" (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chromeos/login/user.h ('k') | chrome/browser/chromeos/login/user_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/login/user_manager.h
diff --git a/chrome/browser/chromeos/login/user_manager.h b/chrome/browser/chromeos/login/user_manager.h
index ccad14125d95e8c63568a68473668e9445b6db88..7e9f6d14191b5d700201d6873edb05ff990a41e4 100644
--- a/chrome/browser/chromeos/login/user_manager.h
+++ b/chrome/browser/chromeos/login/user_manager.h
@@ -8,6 +8,7 @@
#include <string>
+#include "ash/desktop_background/desktop_background_resources.h"
#include "base/memory/singleton.h"
#include "chrome/browser/chromeos/login/user.h"
@@ -38,8 +39,12 @@ class UserManager {
static const char kLoggedInUsers[];
// A dictionary that maps usernames to file paths to their wallpapers.
+ // Deprecated. Will remove this const char after done migration.
static const char kUserWallpapers[];
+ // A dictionary that maps usernames to wallpaper properties.
+ static const char kUserWallpapersProperties[];
+
// A dictionary that maps usernames to file paths to their images.
static const char kUserImages[];
@@ -148,12 +153,17 @@ class UserManager {
// Returns the index of the default wallpapers saved in local state for login
// user if it is known (was previousely set by |SaveWallpaperToLocalState|
- // call). Otherwise, returns a randomly generated index.
- virtual int GetUserWallpaperIndex() = 0;
+ // call). Otherwise, returns the default wallpaper index.
+ virtual int GetLoggedInUserWallpaperIndex() = 0;
+
+ // Set |type| and |index| to the value saved in local state for logged in
+ // user.
+ virtual void GetLoggedInUserWallpaperProperties(User::WallpaperType& type,
+ int& index) = 0;
- // Save the index |wallpaper_index| of the default wallpapers selected by
- // current user to Local State.
- virtual void SaveUserWallpaperIndex(int wallpaper_index) = 0;
+ // Save |type| and |index| chose by logged in user to Local State.
+ virtual void SaveLoggedInUserWallpaperProperties(User::WallpaperType type,
+ int index) = 0;
// Sets user image to the default image with index |image_index|, sends
// LOGIN_USER_IMAGE_CHANGED notification and updates Local State.
« no previous file with comments | « chrome/browser/chromeos/login/user.h ('k') | chrome/browser/chromeos/login/user_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698